#
# This is the user-interface definition of a Shiny web application. You can
# run the application by clicking 'Run App' above.

# Load standard libraries
library(shiny)
library(shinydashboard)

# Load main library
library(hivEstimatesAccuracy)

# Load application modules
modulesPath <- system.file("shiny/modules", package = "hivEstimatesAccuracy")
source(file.path(modulesPath, "inputDataUpload.R"))
source(file.path(modulesPath, "dataSummary.R"))
source(file.path(modulesPath, "dataAdjust.R"))
source(file.path(modulesPath, "createReports.R"))
source(file.path(modulesPath, "settings.R"))

# App globals
titleString <- paste0("HIV Estimate Accuracy v.", packageVersion("hivEstimatesAccuracy"))

# Define application user interface
ui <- tagList(
  shinyjs::useShinyjs(),

  dashboardPage(
    dashboardHeader(title = titleString,
                    titleWidth = 300,
                    .list = tagList(tags$li(tags$a(href = "#",
                                                   icon("cog"),
                                                   span("Settings")),
                                            class = "dropdown"))),
    dashboardSidebar(
      sidebarMenu(
        menuItem("Data upload",        tabName = "upload",      icon = icon("database")),
        menuItem("Input data summary", tabName = "summary",     icon = icon("table")),
        menuItem("Adjustments",        tabName = "adjustments", icon = icon("bolt")),
        menuItem("Reports",            tabName = "reports",     icon = icon("book"))
      )
    ),
    dashboardBody(
      tags$head(
        tags$link(rel = "stylesheet", type = "text/css", href = "./css/style.css")
      ),
      tabItems(
        tabItem(tabName = "upload",
                h2("Data upload"),
                fluidRow(inputDataUploadUI("upload"))),
        tabItem(tabName = "summary",
                h2("Input data summary"),
                fluidRow(dataSummaryUI("summary"))),
        tabItem(tabName = "adjustments",
                h2("Adjustments"),
                fluidRow(dataAdjustUI("adjustments"))),
        tabItem(tabName = "reports",
                h2("Reports"),
                fluidRow(createReportsUI("reports")))
      )
    )
  )
)

# Define application server logic
server <- function(input, output, session)
{
  inputData <- callModule(inputDataUpload, "upload")
  callModule(dataSummary, "summary", inputData)
  adjustedData <- callModule(dataAdjust, "adjustments", inputData)
  reports <- callModule(createReports, "reports", adjustedData)
  callModule(settings, "settings")
}

# Run application
shinyApp(ui, server,
         options = c(display.mode = "normal",
                     test.mode = FALSE,
                     launch.browser = FALSE))
